%define debug_package %{nil}

# select the right architecture
%define fusearch  unknown
%define fuseother unknown
%ifarch i386
%define fusearch  32
%define fuseother 64
%endif
%ifarch x86_64
%define fusearch  64
%define fuseother 32
%endif

# find wrapper information (both architectures are needed in the srpm)
%define wrapper32_url %((grep /wrapper-linux-x86-32- %{_sourcedir}/sources || \
                         grep /wrapper-linux-x86-32- %{_builddir}/sources  || \
                         echo "x unknown") 2>/dev/null | perl -ane 'print("$F[1]")')
%define wrapper32_tar %(basename %{wrapper32_url})
%define wrapper64_url %((grep /wrapper-linux-x86-64- %{_sourcedir}/sources || \
                         grep /wrapper-linux-x86-64- %{_builddir}/sources  || \
                         echo "x unknown") 2>/dev/null | perl -ane 'print("$F[1]")')
%define wrapper64_tar %(basename %{wrapper64_url})

# find wrapper information for the right architecture
%define wrapper_tar unknown
%if "%{fusearch}" == "32"
%define wrapper_tar %{wrapper32_tar}
%define wrapper_src 1
%endif
%if "%{fusearch}" == "64"
%define wrapper_tar %{wrapper64_tar}
%define wrapper_src 2
%endif
%define wrapper_dir %(echo %{wrapper_tar} | perl -pe 's/\.tar\.gz$//')

# find ActiveMQ information
%define activemq_url %((grep /apache-activemq/ %{_sourcedir}/sources || \
                        grep /apache-activemq/ %{_builddir}/sources  || \
                        echo "x unknown") 2>/dev/null | perl -ane 'print("$F[1]")')
%define activemq_tar %(basename %{activemq_url})
%define activemq_version %(echo %{activemq_tar} | perl -pe 's/apache-activemq-//; s/-bin\.tar\.gz$//')
%define is_snapshot %((echo %{activemq_url} | grep SNAPSHOT >/dev/null) && echo 1 || echo 0)

# deduce rpm information
%if %{is_snapshot}
%define pkg_version %(echo %{activemq_version} | perl -pe 's/([\.\-])fuse-.+/$1fuse-SNAPSHOT/')
%define rpm_release %(echo %{activemq_version} | perl -pe 's/.+([\.\-])fuse-//' | perl -pe 's/-.+//')
%else
%define pkg_version %{activemq_version}
%define rpm_release 1
%endif
%define rpm_version %(echo %{pkg_version} | perl -pe 's/-/_/g')

# installation settings
%define activemq_share   /usr/share/activemq
%define activemq_home    %{activemq_share}-%{activemq_version}
%define activemq_alljar  %{_javadir}/activemq-all.jar

Name:		fuse-message-broker
Version:	%{rpm_version}
Release:	%{rpm_release}%{?dist}
Summary:	Fuse Message Broker
Group:		System
License:	ASL 2.0
Url:		http://fusesource.com/products/enterprise-activemq/
Source0:	%{activemq_tar}
Source1:	%{wrapper32_tar}
Source2:	%{wrapper64_tar}
Source3:	activemq.initd
Source4:	favicon.ico
Source5:	sources
BuildRoot:	%{_tmppath}/%{name}-%{pkgversion}-%{release}-root
BuildRequires:	perl
Requires:	java >= 0:1.5.0
Requires:	jpackage-utils

%description
Fuse Message Broker is an open source messaging platform based on
Apache ActiveMQ that is productized and supported by the people who
wrote the code. Fuse Message Broker is the JMS platform of choice for
scalable, high-performance SOA infrastructure to connect processes
across heterogeneous systems.

%package client
Summary:	Fuse Message Broker Client jar
Group:		System

%description client
Client jar for the Fuse Message Broker.

%prep
if [ "x%{fusearch}" = "xunknown" ]; then
    echo "ERROR: unsupported architecture: %{_arch}"
    exit 1
fi
#echo "ActiveMQ version: %{activemq_version}"
#echo "RPM version:      %{rpm_version} %{rpm_release}%{?dist}"
%if "%{wrapper_tar}" != "unknown"
%setup -q -n %{wrapper_dir} -T -b %{wrapper_src}
cd ..
%endif
%setup -q -n apache-activemq-%{pkg_version}

%build
# copy the service script to the bin directory
install -m 0755 %{SOURCE3} bin/service
# use the wrapper files
%if "%{wrapper_tar}" != "unknown"
install -m 0755 ../%{wrapper_dir}/bin/wrapper bin/linux-x86-%{fusearch}/wrapper
install -m 0755 ../%{wrapper_dir}/lib/libwrapper.so bin/linux-x86-%{fusearch}/libwrapper.so
install -m 0755 ../%{wrapper_dir}/lib/wrapper.jar bin/wrapper.jar
%endif
# symlink the wrapper binaries
for name in wrapper libwrapper.so; do
  ln -s linux-x86-%{fusearch}/$name bin/$name
done
# remove the unwanted binary directories
rm -fr bin/linux-x86-%{fuseother} bin/macosx
# temporary hack to set the proper configuration paths in XML files while DEV-3055 gets fixed
grep -l '{activemq.base}/conf/' `find webapps -name '*.xml'` | while read path; do
    perl -pi -e 's#\{activemq\.base\}/conf/#{activemq.conf}/#' $path
done
# temporary hack to use a working favicon.ico file and link it from the admin web app (DEV-4276)
install -m 0644 %{SOURCE4} webapps
ln webapps/favicon.ico webapps/admin/favicon.ico

%install
rm -fr %{buildroot}
mkdir -p %{buildroot}%{activemq_home}
mv * %{buildroot}%{activemq_home}
# move the activemq-all jar away (it will be part of the client rpm)
mkdir -p %{buildroot}%{_javadir}
mv %{buildroot}%{activemq_home}/activemq-all-*.jar %{buildroot}%{_javadir}/activemq-all-%{activemq_version}.jar

%clean
rm -fr %{buildroot}

%post
[ -e %{activemq_share} ] && rm -f %{activemq_share} || true
ln -s activemq-%{activemq_version} %{activemq_share}

%post client
[ -e %{activemq_alljar} ] && rm -f %{activemq_alljar} || true
ln -s activemq-all-%{activemq_version}.jar %{activemq_alljar}

%postun
rm -f %{activemq_share}
cd /usr/share
last=`ls -dt activemq-* 2>/dev/null | head -1`
[ "x$last" != "x" ] && ln -s $last %{activemq_share} || true

%postun client
rm -f %{activemq_alljar}
cd %{_javadir}
last=`ls -dt activemq-all-*.jar 2>/dev/null | head -1`
[ "x$last" != "x" ] && ln -s $last %{activemq_alljar} || true

%preun
# remove symlinks that may have been created when patching ActiveMQ
find %{activemq_home}/lib -type l -exec rm -f \{\} \;

%files
%defattr(-,root,root,-)
%{activemq_home}

%files client
%defattr(-,root,root,-)
%{_javadir}/*.jar
